# -*- coding: utf-8 -*-

# Copyright: © 2013 Olivier Larchevêque <olivier.larcheveque@auf.org>
#
# This file is part of auf-piwik.
#
# auf-piwik is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# auf-piwik is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with auf-piwik.  If not, see <http://www.gnu.org/licenses/>.


import os
import sys
import optparse
import subprocess

from settings import Settings, mod_logging

# Mettre dans le path, le répertoire où sont déposés les fichiers
sys.path.append(os.path.dirname(__file__))

option_parser = optparse.OptionParser(
    usage=u'Usage: %prog config_file [options]',
    description=u"Importe les fichiers access.log dans un site Piwik"
)
option_parser.add_option(
    '--verbose', '-v', dest='verbose', action="count", default=False,
    help=u"Active le mode verbeux",
)
option_parser.add_option(
    '--dry-run', dest='dry_run', action="count", default=False,
    help=u"Pas d'import",
)

options, filenames = option_parser.parse_args(sys.argv[1:])

if len(filenames) != 1:
    option_parser.error(u"La configuration est obligatoire")

piwik_settings = Settings(filenames[0])
logging = piwik_settings.get_logger('piwik.py')

script = ['python', 'auf_import_logs.py', ]


if options.verbose:
    logging.setLevel(mod_logging.DEBUG)
    script.append('--logging=DEBUG')

if options.dry_run:
    script.append('--logging=DEBUG')
    script.append('--dry-run')

script.append('--url=%s' % piwik_settings.piwik_url)

processes = []

site_sections = [s for s in piwik_settings.config.sections()
                 if s.startswith('http')]
for site in site_sections:
    options = []
    for k, v in piwik_settings.config.items(site):
        options.append('--%s=%s' % (k, v))
    options.append('--site-name=%s' % (site, ))
    options = [o.decode('utf-8') for o in options]
    cmd = script + options
    logging.debug(" ".join(cmd))
    proc = subprocess.Popen(cmd, stdout=subprocess.PIPE)
    proc.site = site
    processes.append(proc)

status = [(p.wait(), p.site) for p in processes]

for code, site in status:
    if code == 0:
        logging.info("%s: OK" % site)
    else:
        logging.error("%s: KO" % site)
