# -*- coding: utf-8 -*-

import ConfigParser
import dictconfig
import logging as mod_logging


DEFAULT_PIWIK_URL = "http://piwik.auf.org/"
DEFAULT_CACHE = "/var/cache/auf-piwik/"

LOGGING = {
    'version': 1,
    'disable_existing_loggings': True,
    'formatters': {
        'verbose': {
            'format': '%(levelname)s %(asctime)s \
[%(name)s] %(process)d %(message)s'
        },
    },
    'handlers': {
        'console': {
            'level': 'DEBUG',
            'class': 'logging.StreamHandler',
            'formatter': 'verbose'
        },
    },
    'loggers': {
        '': {
            'handlers': ['console', ],
            'level': 'DEBUG',
            'propagate': False,
        },
    }
}


class Settings(object):
    """
    Classe qui gère le cas de la conf globale multisites et mono-site pour le
    script.
    """
    def __init__(self, config_file=None):
        #try:
        self.config = ConfigParser.ConfigParser()
        self.config_file = config_file

        try:
            self.config.readfp(open(self.config_file))
        except:
            pass

        try:
            self.section_global = dict(self.config.items('global'))
        except:
            self.section_global = {'logging': 'ERROR', }

        try:
            self.piwik_url = self.section_global.get(
                'piwik_url', DEFAULT_PIWIK_URL)
        except:
            self.piwik_url = DEFAULT_PIWIK_URL

        try:
            self.piwik_cache = self.section_global.get('cache', DEFAULT_CACHE)
        except:
            self.piwik_cache = DEFAULT_CACHE

        dictconfig.dictConfig(LOGGING)

    def get_logger(self, name='piwik'):
        logger = mod_logging.getLogger(name)
        logging_level = self.section_global.get('logging', 'ERROR')
        level = getattr(mod_logging, logging_level)
        logger.setLevel(level)
        return logger
